==> ejc-bidprice-impl-3.0.0-20230209.024801-5-sources.jar: com/ejianc/business/bidprice/material/bean/MaterialPicketageSupplierEntity.java <==
package com.ejianc.business.bidprice.material.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 材料定标-供应商
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bidprice_material_picketage_supplier")
public class MaterialPicketageSupplierEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="picketage_detail_id")
    private Long picketageDetailId; // 清单id
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="mny")
    private BigDecimal mny; // 金额
    @TableField(value="supplier_id")
    private Long supplierId; // 应商id
    @TableField(value="supplier_name")
    private String supplierName; // 供应商名称
    
    
    

    public Long getPicketageDetailId() {
        return picketageDetailId;
    }

    public void setPicketageDetailId(Long picketageDetailId) {
        this.picketageDetailId = picketageDetailId;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    
}

==> ejc-bidprice-impl-3.0.0-20240228.054944-139-sources.jar: com/ejianc/business/bidprice/material/bean/MaterialPicketageSupplierEntity.java <==
package com.ejianc.business.bidprice.material.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 材料定标-供应商
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bidprice_material_picketage_supplier")
public class MaterialPicketageSupplierEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="picketage_id")
    private Long picketageId; // 定标主表id
    @TableField(value="picketage_detail_id")
    private Long picketageDetailId; // 清单id
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="mny")
    private BigDecimal mny; // 金额
    @TableField(value="supplier_id")
    private Long supplierId; // 应商id
    @TableField(value="supplier_name")
    private String supplierName; // 供应商名称


    public Long getPicketageId() {
        return picketageId;
    }

    public void setPicketageId(Long picketageId) {
        this.picketageId = picketageId;
    }

    public Long getPicketageDetailId() {
        return picketageDetailId;
    }

    public void setPicketageDetailId(Long picketageDetailId) {
        this.picketageDetailId = picketageDetailId;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    
}
